@@ -1,17 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from iss import util
-from iss.error_models import ErrorModel
-
-from Bio.Seq import MutableSeq
-from Bio.SeqRecord import SeqRecord
-from scipy import stats
-
-import sys
-import random
 import numpy as np
 
+from iss.error_models import ErrorModel
+
 
 class KDErrorModel(ErrorModel):
     """KDErrorModel class.
@@ -28,29 +21,33 @@ class KDErrorModel(ErrorModel):
     - the insertion and deletion rates for each position (for R1 and R2)
     """
 
-    def __init__(self, npz_path):
+    def __init__(self, npz_path, fragment_length=None, fragment_sd=None, store_mutations=False):
         super().__init__()
         self.npz_path = npz_path
-        self.error_profile = self.load_npz(npz_path, 'kde')
+        self.error_profile = self.load_npz(npz_path, "kde")
+        self.store_mutations = store_mutations
 
-        self.read_length = self.error_profile['read_length']
-        self.i_size_cdf = self.error_profile['insert_size']
+        self.read_length = self.error_profile["read_length"]
+        self.i_size_cdf = self.error_profile["insert_size"]
 
-        self.mean_forward = self.error_profile['mean_count_forward']
-        self.mean_reverse = self.error_profile['mean_count_reverse']
+        self.fragment_length = fragment_length
+        self.fragment_sd = fragment_sd
 
-        self.quality_forward = self.error_profile['quality_hist_forward']
-        self.quality_reverse = self.error_profile['quality_hist_reverse']
+        self.mean_forward = self.error_profile["mean_count_forward"]
+        self.mean_reverse = self.error_profile["mean_count_reverse"]
 
-        self.subst_choices_for = self.error_profile['subst_choices_forward']
-        self.subst_choices_rev = self.error_profile['subst_choices_reverse']
+        self.quality_forward = self.error_profile["quality_hist_forward"]
+        self.quality_reverse = self.error_profile["quality_hist_reverse"]
 
-        self.ins_for = self.error_profile['ins_forward']
-        self.ins_rev = self.error_profile['ins_reverse']
-        self.del_for = self.error_profile['del_forward']
-        self.del_rev = self.error_profile['del_reverse']
+        self.subst_choices_for = self.error_profile["subst_choices_forward"]
+        self.subst_choices_rev = self.error_profile["subst_choices_reverse"]
 
-        self.error_profile = ''  # discard the error profile after reading
+        self.ins_for = self.error_profile["ins_forward"]
+        self.ins_rev = self.error_profile["ins_reverse"]
+        self.del_for = self.error_profile["del_forward"]
+        self.del_rev = self.error_profile["del_reverse"]
+
+        self.error_profile = ""  # discard the error profile after reading
 
     def gen_phred_scores(self, cdfs, orientation):
         """Generate a list of phred scores based on cdfs and mean bins
@@ -67,9 +64,9 @@ class KDErrorModel(ErrorModel):
             list: a list of phred scores
         """
         # choose which mean bin to use
-        if orientation == 'forward':
+        if orientation == "forward":
             mean = self.mean_forward
-        elif orientation == 'reverse':
+        elif orientation == "reverse":
             mean = self.mean_reverse
 
         norm_mean = mean / sum(mean)
@@ -86,7 +83,7 @@ class KDErrorModel(ErrorModel):
         for cdf in cdfs_bin:
             random_quality = np.searchsorted(cdf, np.random.rand())
             phred_list.append(random_quality)
-        return phred_list[:self.read_length]
+        return phred_list[: self.read_length]
 
     def random_insert_size(self):
         """Draw a random insert size from the insert size cdf
